gchecky.model.merchant_calculation_callback_t

Package gchecky :: Module model :: Class merchant_calculation_callback_t |
[hide private]
[frames] | no frames]

# Class merchant_calculation_callback_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    merchant_calculation_callback_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``merchant-calculation-callback``'`` The document's unique xml tag name.
| serial_number = `ID:PATH(@serial-number):REQ:EMPTY`
| buyer_id = `Long:PATH(buyer-id):OPT`
| buyer_language = `LanguageCode:PATH(buyer-language):REQ:EMPTY`
| calculate = `Node:PATH(calculate):REQ:{ calculate_t }`
| shopping_cart = `Node:PATH(shopping-cart):REQ:{ shopping_cart_t }`
| _fields = ``{``'``buyer_id``'``:` Long:PATH(buyer-id):OPT`,` `'``buyer_languag``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'buyer_id': Long:PATH(buyer-id):OPT,
       'buyer_language': LanguageCode:PATH(buyer-language):REQ:EMPTY,
       'calculate': Node:PATH(calculate):REQ:{ calculate_t },
       'serial_number': ID:PATH(@serial-number):REQ:EMPTY,
       'shopping_cart': Node:PATH(shopping-cart):REQ:{ shopping_cart_t }}